@@ -1,6 +1,6 @@
 from bread import views as breadviews
 from bread.utils.urls import autopath, default_model_paths, model_urlname, reverse_model
-from bread.views import AddView
+from bread.views import AddView, EditView
 from django.views.generic import RedirectView
 
 import basxconnect.core.views.tag_views
@@ -14,6 +14,8 @@ from basxconnect.core.views.person import (
 
 from . import models
 from .views.relationship_views import AddRelationshipView, EditRelationshipView
+from .views.term import TermsBrowseView
+from .views.vocabulary import VocabularyBrowseView
 from .wizards.add_person import AddPersonWizard
 
 urlpatterns = [
@@ -117,9 +119,14 @@ urlpatterns = [
     ),
     *default_model_paths(models.RelationshipType),
     *default_model_paths(
-        models.Term, addview=AddView._with(fields=["term", "vocabulary"])
+        models.Term,
+        addview=AddView._with(fields=["term", "vocabulary"]),
+        browseview=TermsBrowseView,
+    ),
+    *default_model_paths(
+        models.Vocabulary,
+        browseview=VocabularyBrowseView,
     ),
-    *default_model_paths(models.Vocabulary),
     *default_model_paths(models.Postal),
     *default_model_paths(models.Phone),
     *default_model_paths(models.Web),
@@ -183,6 +190,13 @@ urlpatterns = [
         person_modals_views.PersonAssociationEditTagsView.as_view(),
         urlname=model_urlname(models.PersonAssociation, "ajax_edit_tags"),
     ),
+    *[
+        autopath(
+            EditView._with(model=m, fields=["personnumber", "type"]).as_view(),
+            urlname=model_urlname(m, f"{m._meta.model_name}_ajax_edit_metadata"),
+        )
+        for m in [models.NaturalPerson, models.LegalPerson, models.PersonAssociation]
+    ],
     autopath(
         person_details_views.confirm_delete_email,
         urlname=model_urlname(models.Email, "delete"),
