@@ -1,6 +1,6 @@
 from bread import layout as layout
 from bread import menu
-from bread.layout.base import DEVMODE_KEY
+from bread.layout import DEVMODE_KEY
 from bread.utils.links import Link
 from bread.utils.urls import reverse, reverse_model
 from django.utils.translation import gettext_lazy as _
@@ -40,7 +40,6 @@ menu.registeritem(
 )
 
 persongroup = menu.Group(_("Persons"), iconname="group")
-settingsgroup = menu.Group(_("Settings"), iconname="settings", order=100)
 
 menu.registeritem(
     menu.Item(
@@ -55,7 +54,7 @@ menu.registeritem(
             reverse("basxconnect.core.views.settings_views.generalsettings"),
             _("General"),
         ),
-        settingsgroup,
+        menu.settingsgroup,
     )
 )
 
@@ -65,7 +64,7 @@ menu.registeritem(
             reverse("basxconnect.core.views.settings_views.personsettings"),
             _("Persons"),
         ),
-        settingsgroup,
+        menu.settingsgroup,
     )
 )
 
@@ -75,6 +74,6 @@ menu.registeritem(
             reverse("basxconnect.core.views.settings_views.relationshipssettings"),
             _("Relationships"),
         ),
-        settingsgroup,
+        menu.settingsgroup,
     )
 )
