@@ -3,6 +3,7 @@ from typing import List
 
 import mailchimp_marketing
 from django.conf import settings
+from dynamic_preferences.registries import global_preferences_registry
 from mailchimp_marketing.api_client import ApiClientError
 
 from basxconnect.mailer_integration.abstract import mailer
@@ -14,25 +15,32 @@ from basxconnect.mailer_integration.models import Interest
 
 
 class Mailchimp(mailer.AbstractMailer):
-    def __init__(self) -> None:
-        self.client = mailchimp_marketing.Client()
-        self.client.set_config(
-            {"api_key": settings.MAILCHIMP_API_KEY, "server": settings.MAILCHIMP_SERVER}
+    def _dynamic_setting(self, name: str):
+        return global_preferences_registry.manager()[name]
+
+    def _client(self):
+        client = mailchimp_marketing.Client()
+        client.set_config(
+            {
+                "api_key": self._dynamic_setting("mailchimp__api_key"),
+                "server": self._dynamic_setting("mailchimp__server"),
+            }
         )
+        return client
 
     def name(self) -> str:
         return "Mailchimp"
 
     def get_person_count(self) -> int:
-        return self.client.lists.get_segment(
-            list_id=settings.MAILCHIMP_LIST_ID,
-            segment_id=settings.MAILCHIMP_SEGMENT_ID,
+        return self._client().lists.get_segment(
+            list_id=self._dynamic_setting("mailchimp__list_id"),
+            segment_id=self._dynamic_setting("mailchimp__segment_id"),
         )["member_count"]
 
     def get_persons(self, count: int, offset: int) -> List[MailerPerson]:
-        segment = self.client.lists.get_segment_members_list(
-            list_id=settings.MAILCHIMP_LIST_ID,
-            segment_id=settings.MAILCHIMP_SEGMENT_ID,
+        segment = self._client().lists.get_segment_members_list(
+            list_id=self._dynamic_setting("mailchimp__list_id"),
+            segment_id=self._dynamic_setting("mailchimp__segment_id"),
             count=count,
             offset=offset,
             include_cleaned=True,
@@ -51,14 +59,15 @@ class Mailchimp(mailer.AbstractMailer):
         ]
 
     def delete_person(self, email: str):
-        self.client.lists.delete_list_member(
-            settings.MAILCHIMP_LIST_ID, compute_email_hash(email)
+        self._client().lists.delete_list_member(
+            self._dynamic_setting("mailchimp__list_id"),
+            compute_email_hash(email),
         )
 
     def put_person(self, person: MailerPerson, **kwargs):
         email_hash = compute_email_hash(person.email)
-        self.client.lists.set_list_member(
-            settings.MAILCHIMP_LIST_ID,
+        self._client().lists.set_list_member(
+            self._dynamic_setting("mailchimp__list_id"),
             email_hash,
             {
                 "email_address": person.email,
@@ -77,20 +86,27 @@ class Mailchimp(mailer.AbstractMailer):
                 **kwargs,
             },
         )
-        if hasattr(settings, "MAILCHIMP_TAG"):
-            self.client.lists.update_list_member_tags(
-                settings.MAILCHIMP_LIST_ID,
-                email_hash,
-                {"tags": [{"name": settings.MAILCHIMP_TAG, "status": "active"}]},
-            )
+        self._client().lists.update_list_member_tags(
+            self._dynamic_setting("mailchimp__list_id"),
+            email_hash,
+            {
+                "tags": [
+                    {
+                        "name": self._dynamic_setting("mailchimp__tag"),
+                        "status": "active",
+                    }
+                ]
+            },
+        )
 
     def add_person(self, person: MailerPerson):
         self.put_person(person, status=person.status)
 
     def email_exists(self, email: str) -> bool:
         try:
-            self.client.lists.get_list_member(
-                settings.MAILCHIMP_LIST_ID, compute_email_hash(email)
+            self._client().lists.get_list_member(
+                self._dynamic_setting("mailchimp__list_id"),
+                compute_email_hash(email),
             )
         except ApiClientError as e:
             if e.status_code == 404:
@@ -99,23 +115,29 @@ class Mailchimp(mailer.AbstractMailer):
         return True
 
     def change_email_address(self, old_email: str, new_email: str):
-        self.client.lists.update_list_member(
-            settings.MAILCHIMP_LIST_ID,
+        self._client().lists.update_list_member(
+            self._dynamic_setting("mailchimp__list_id"),
             compute_email_hash(old_email),
             {"email_address": new_email},
         )
 
     def get_interests(self):
-        return [
-            MailingInterest(interest["id"], interest["name"])
-            for interest in self.client.lists.list_interest_category_interests(
-                settings.MAILCHIMP_LIST_ID,
-                settings.MAILCHIMP_INTERESTS_CATEGORY_ID,
-            )["interests"]
-        ]
+        interests_category_id = self._dynamic_setting(
+            "mailchimp__interests_category_id"
+        )
+        if interests_category_id:
+            return [
+                MailingInterest(interest["id"], interest["name"])
+                for interest in self._client().lists.list_interest_category_interests(
+                    self._dynamic_setting("mailchimp__list_id"),
+                    interests_category_id,
+                )["interests"]
+            ]
+        else:
+            return []
 
     def tag(self) -> str:
-        return "Imported from Mailchimp"
+        return self._dynamic_setting("mailchimp__basxconnect_tag")
 
 
 def compute_interests_dict(person) -> dict:
